// Copyright 2019 github.com. All rights reserved.
// Use of this source code is governed by github.com.

package v1

import (
	"smart-enterprise-management-gateway/param/base"
	pb_v1 "smart-enterprise-management-gateway/pb/v1"
)


type ProjectAddBody struct {
	// 项目名称
	Name                 string   `form:"name" json:"name"`
	// 项目效果图
	ProjectEffectPic []string `form:"project_effect_pic" json:"project_effect_pic"`
	// 工程所在地
	Location                 string   `form:"location" json:";location"`
	// 安监备案号
	SafetyRecordNo       string   `form:"safety_record_no" json:"safety_record_no"`
	// 项目负责人
	ProjectLeader        string   `form:"project_leader" json:"project_leader"`
	// 项目负责人电话
	Phone   string   `form:"phone" json:"phone"`
	// 项目平面图
	ProjectPlan          []string   `form:"project_plan" json:"project_plan"`
	// 项目功能
	ProjectFunction      string   `form:"project_function" json:"project_function"`
	// 项目类型
	ProjectType          string   `form:"project_type" json:"project_type"`
	// 工程造价(万)
	Price                float64  `form:"price" json:"price"`
	// 项目介绍
	Desc                 string   `form:"desc" json:"desc"`
	//建筑面积(单位m2)
	CoveredArea          float64  `form:"covered_area" json:"covered_area"`
	// 总层数
	TotalLevel           int32    `form:"total_level" json:"total_level"`
	// 建筑层数 eg:主楼地上23层,地下2层；裙楼地上32层，地下3层
	BuildingStorey       string   `form:"building_storey" json:"building_storey"`
	// 施工单位
	Construction         string   `form:"construction" json:"construction"`
	// 建设单位
	Development          string   `form:"development" json:"development"`
	// 监理单位
	Oversee              string   `form:"oversee" json:"oversee"`
	// 设计单位
	Design               string   `form:"design" json:"design"`
	// 勘察单位
	Exploration          string   `form:"exploration" json:"exploration"`
	// 经度
	Lon                  float64  `form:"lon" json:"lon"`
	// 纬度
	Lat                  float64  `form:"lat" json:"lat"`
	StartDay int64 `form:"start_day" json:"start_day"`
	EndDay int64 `form:"end_day" json:"end_day"`

}

type ProjectAddRequest struct {
	base.Header
	ProjectAddBody
}

type ProjectAddResponse struct {
	base.Result
}

type ProjectListQuery struct {
	Page int32 `form:"page"`
	Filter string `form:"filter"`
	FilterStatus string `form:"filter_status"`
	PageSize int32 `form:"page_size"`
}

type ProjectListRequest struct {
	base.Header
	ProjectListQuery
}

type ProjectListResponse struct {
	base.Result
	Data pb_v1.ProjectListReply `json:"data"`
}

type ProjectUserListQuery struct {
	Page int32 `form:"page"`
	Filter string `form:"filter"`
}

type ProjectUserListRequest struct {
	base.Header
	ProjectUserListQuery
}

type ProjectUserListResponse struct {
	base.Result
	Data pb_v1.ProjectUserListReply `json:"data"`
}

type EnableProjectUserBody struct {
	Id int64 `form:"id"`
	Enable bool `form:"enable"`
}

type EnableProjectUserRequest struct {
	base.Header
	EnableProjectUserBody
}

type EnableProjectUserResponse struct{
	base.Result
}

type ProjectUserPasswordResetBody struct {
	// 账号id
	Id int64 `form:"id"`
	Password string `form:"password"`
}

type ProjectUserPasswordResetRequest struct{
	base.Header
	ProjectUserPasswordResetBody

}

type ProjectUserPasswordResetResponse struct {
	base.Result
}

type ProjectDistrictRequest struct {
	base.Header
}

type ProjectDistrictResponse struct {
	base.Result
	Data pb_v1.ProjectDistrictReply `json:"data"`
}

type ProjectUpdateBody struct {
	Id                   int64    `json:"id" form:"id"`
	Name                 string   `json:"name" form:"name"`
	Location             string   `json:"location" form:"location"`
	SafetyRecordNo       string   `json:"safety_record_no" form:"safety_record_no"`
	ProjectLeader        string   `json:"project_leader" form:"project_leader"`
	Phone                string   `json:"phone" form:"phone"`
	ProjectNo            string   `json:"project_no" form:"project_no"`
	ProjectPlan          []string   `json:"project_plan" form:"project_plan"`
	ProjectFunction      string   `json:"project_function" form:"project_function"`
	ProjectType          string   `json:"project_type" form:"project_type"`
	Price                float64  `json:"price" form:"price"`
	Desc                 string   `json:"desc" form:"desc"`
	CoveredArea          float64  `json:"covered_area" form:"covered_area"`
	TotalLevel           int32    `json:"total_level" form:"total_level"`
	BuildingStorey       string   `json:"building_storey" form:"building_storey"`
	Construction         string   `json:"construction" form:"construction"`
	Development          string   `json:"development" form:"development"`
	Oversee              string   `json:"oversee" form:"oversee"`
	Design               string   `json:"design" form:"design"`
	Exploration          string   `json:"exploration" form:"exploration"`
	Lon                  float64  `json:"lon" form:"lon"`
	Lat                  float64  `json:"lat" form:"lat"`
	ProjectEffectPic     []string   `json:"project_effect_pic" form:"project_effect_pic"`
	StartDay             int64    `json:"start_day" form:"start_day"`
	EndDay               int64    `json:"end_day" form:"end_day"`
}

type ProjectUpdateRequest struct {
	base.Header
	ProjectUpdateBody
}

type ProjectUpdateResponse struct {
	base.Result
}

type ProjectInfoPath struct {
	Id int64 `uri:"id"`
}
type ProjectInfoRequest struct {
	base.Header
	ProjectInfoPath
}

type ProjectInfoResponse struct {
	base.Result
	Data pb_v1.ProjectInfoReply `json:"data"`
}

type ProjectDelPath struct {
	Id int64 `uri:"id"`
}

type ProjectDelRequest struct {
	base.Header
	ProjectDelPath
}

type ProjectDelResponse struct {
	base.Result
}

type ProjectFinishPath struct {
	Id int64 `uri:"id"`
}

type ProjectFinishRequest struct {
	base.Header
	ProjectFinishPath
}

type ProjectFinishResponse struct {
	base.Result
}

