// Copyright 2019 github.com. All rights reserved.
// Use of this source code is governed by github.com.

package v1

import (
	"smart-enterprise-management-gateway/param/base"
	"smart-enterprise-management-gateway/pb/v1"
)


type RegisterBody struct {
	// 公司名称
	Name string `form:"name" json:"name"`
	// 统一社会信用码
	SocialCode string `form:"social_code" json:"social_code"`
	// 法定代表人
	LegalPerson string `form:"legal_person" json:"legal_person"`
	// 证件号
	IdCert string `form:"id_cert" json:"id_cert"`
	// 营业执照
	BusinessLicense []string `form:"business_license" json:"business_license"`
	// 用户名
	UserName string `form:"user_name" json:"user_name"`
	// 密码
	Passwd string `form:"passwd" json:"passwd"`
	// 业务联系人
	BusinessContact string `form:"business_contact" json:"business_contact"`
	// 业务联系人电话
	BusinessContactPhone string `form:"business_contact_phone" json:"business_contact_phone"`
	// 业务负责人
	BusinessResponsible string `form:"business_responsible" json:"business_responsible"`
	// 业务负责人电话
	BusinessResponsiblePhone string `form:"business_responsible_phone" json:"business_responsible_phone"`
	EmergencyContact         string `form:"emergency_contact" json:"emergency_contact"`
	EmergencyContactPhone    string `form:"emergency_contact_phone" json:"emergency_contact_phone"`
	// 注册状态 0 待审核 1 通过 2 未通过
	Status               int32    `form:"status" json:"status"`
	Province             string   `form:"province" json:"province"`
	City                 string   `form:"city" json:"city"`
	Zone                 string   `form:"zone" json:"zone"`
	Verify string `form:"verify"`
}

type RegisterRequest struct {
	RegisterBody
}

type RegisterResponse struct {
	base.Result
	Data v1.RegisterReply `json:"data"`
}

type LoginBody struct {
	User string `form:"user"`
	Password string `form:"password"`
	Verify string `form:"verify"`
	Captcha string `form:"captcha"`
}

type LoginRequest struct {
	LoginBody
}

type LoginData struct {
	Uid int64 `json:"uid"`
	Token string `json:"token"`
	RefreshToken string `json:"refresh_token"`
}

type LoginResponse struct {
	base.Result
	Data LoginData `json:"data"`
}

type TokenRequest struct {
	base.Header
}

type TokenResponse struct {
	base.Result
	Data string `json:"data"`
}


type VcodeQuery struct {
	Phone string `form:"phone"`
}

type VcodeRequest struct {
	VcodeQuery
}

type VcodeResponse struct {
	base.Result
	Data v1.GetVcodeReply `json:"data"`
}

type FindPasswdVerifyBody struct {
	Phone string `form:"phone"`
	Verify string `form:"verify"`
	Vcode uint32 `form:"vcode"`
	Captcha string `form:"captcha"`
}

type FindPasswdVerifyRequest struct {
	FindPasswdVerifyBody
}

type FindPasswdVerifyResponse struct {
	base.Result
}

type SetPasswdBody struct {
	Phone string `form:"phone"`
	Passwd string `form:"passwd"`
	Vcode uint32 `form:"vcode"`
}

type SetPasswdRequest struct {
	SetPasswdBody
}

type SetPasswdResponse struct {
	base.Result
}

type CompanyApproveStatusQuery struct {
	SocialCode string `form:"social_code"`
}
type CompanyApproveStatusRequest struct {
	base.Header
	CompanyApproveStatusQuery
}
type CompanyApproveStatusResponse struct {
	base.Result
	Data v1.CompanyApproveStatusReply `json:"data"`
}

type ChangePasswdBody struct {
	Old string `form:"old"`
	New string `form:"new"`
}

type ChangePasswdRequest struct {
	base.Header
	ChangePasswdBody
}

type ChangePasswdResponse struct {
	base.Result
}

type LogListQuery struct {
	Page int32 `form:"page"`
	Start int64 `form:"start"`
	End int64 `form:"end"`
}

type LogListRequest struct {
	base.Header
	LogListQuery
}

type LogListResponse struct {
	base.Result
	Data v1.LogListReply `json:"data"`
}

type CaptchaIdRequest struct {

}

type CaptchaIdData struct {
	CaptureId string `json:"capture_id"`
}

type CaptchaIdResponse struct {
	base.Result
	Data CaptchaIdData `json:"data"`
}

type CaptchaPngPath struct {
	CaptchaId string `uri:"captcha_id"`
}

type CaptchaPngRequest struct {
	CaptchaPngPath
}

type CaptchaPngResponse struct {
}

type MapReqeust struct {
}
type MapData struct {
	Url string `json:"url"`
}
type MapResponse struct {
	base.Result
	Data MapData `json:"data"`
}

type PublicityQuery struct {
	DeviceCode int `form:"device_code"`
	Provider string `form:"provider"`
}

type PublicityRequest struct {
	PublicityQuery
}

type PublicityItem struct {
	Name                 string                     `json:"name"`
	SocialCode           string                     `json:"social_code"`
}

type PublicityData struct {
	List []PublicityItem `json:"list"`
}
type PublicityResponse struct {
	base.Result
	Data PublicityData `json:"data"`
}

type MailUpdateQuery struct {
	Token string `form:"token"`
}
type MailUpdateRequest struct {
	MailUpdateQuery
}

type MailUpdateResponse struct {
	base.Result
}

type MailPrepareBody struct {
	Email string `form:"email"`
	Password string `form:"password"`
}
type MailPrepareRequest struct {
	base.Header
	MailPrepareBody
}

type MailPrepareResponse struct {
	base.Result
}

type PhoneUpdateBody struct {
	Phone string `form:"phone"`
	Vcode uint32 `form:"vcode"`
}

type PhoneUpdateRequest struct {
	base.Header
	PhoneUpdateBody
}

type PhoneUpdateResponse struct {
	base.Result
}

type UserInfoRequest struct {
	base.Header
}

type UserInfoResponse struct {
	base.Result
	Data v1.UserInfoReply `json:"data"`
}

type TmpTokenQuery struct {
	ProjectId int64 `form:"project_id"`
}

type TmpTokenRequest struct{
	base.Header
	TmpTokenQuery
}

type TmpTokenData struct {
	Token string `json:"token"`
}
type TmpTokenResponse struct {
	base.Result
	Data TmpTokenData `json:"data"`
}